@@ -9,8 +9,10 @@
 #' @param colline Line colour
 #' @param colpnt Point colour
 #' @param colbound Background colour for plot type \code{"bound"}
-#' @param ymin Minimum plot extend in vertical direction
+#' @param ymin Minimum plot extent in vertical direction
 #' @param ymax Maximum plot extent in vertical direction
+#' @param xmin Minimum plot extent in horizontal direction
+#' @param xmax Maximum plot extent in horizontal direction
 #' @param xlab x-axis label
 #' @param ylab y-axis label
 #' @param main Plot title
@@ -42,14 +44,23 @@
 plotEvents <- function(data, dates = NULL, events, type = "lineover",
                        colline = "red", colpnt = "blue", colbound = "red",
                        ymin = min(data), ymax = max(data),
+                       xmin = NULL, xmax = NULL,
                        xlab = "", ylab = "", main = "events") {
 
+  if (is.null(xmin) & is.null(xmax) & is.null(dates)) {
+    xmin = 1
+    xmax = length(data)
+  } else if (is.null(xmin) & is.null(xmax) & !is.null(dates)) {
+    xmin = min(dates)
+    xmax = max(dates)
+  }
+
     if (type == "lineover") {
 
       if (!is.null(dates)) {
-        plot(data~dates,type="o",pch=20,cex=0.7,ylim=c(ymin,ymax),main=main, xlab=xlab, ylab=ylab, mgp = c(1.7, 0.6, 0))
+        plot(data~dates,type="o",pch=20,cex=0.7,ylim=c(ymin,ymax),xlim=c(xmin,xmax),main=main, xlab=xlab, ylab=ylab, mgp = c(1.7, 0.6, 0))
       } else {
-        plot(data,type="o",pch=20,cex=0.7,ylim=c(ymin,ymax),main=main, xlab=xlab, ylab=ylab, mgp = c(1.7, 0.6, 0))
+        plot(data,type="o",pch=20,cex=0.7,ylim=c(ymin,ymax),xlim=c(xmin,xmax),main=main, xlab=xlab, ylab=ylab, mgp = c(1.7, 0.6, 0))
       }
 
       extevents = eventid = list()
@@ -80,9 +91,9 @@ plotEvents <- function(data, dates = NULL, events, type = "lineover",
     } else if (type=="bound") {
 
       if (!is.null(dates)) {
-        plot(data~dates,type="o",pch=20,cex=0.7,ylim=c(ymin,ymax),main=main, xlab=xlab, ylab=ylab, mgp = c(1.7, 0.6, 0))
+        plot(data~dates,type="o",pch=20,cex=0.7,ylim=c(ymin,ymax),xlim=c(xmin,xmax),main=main, xlab=xlab, ylab=ylab, mgp = c(1.7, 0.6, 0))
       } else {
-        plot(data,type="o",pch=20,cex=0.7,ylim=c(ymin,ymax),main=main, xlab=xlab, ylab=ylab, mgp = c(1.7, 0.6, 0))
+        plot(data,type="o",pch=20,cex=0.7,ylim=c(ymin,ymax),xlim=c(xmin,xmax),main=main, xlab=xlab, ylab=ylab, mgp = c(1.7, 0.6, 0))
       }
 
       if (!is.null(dates)) {
@@ -109,9 +120,9 @@ plotEvents <- function(data, dates = NULL, events, type = "lineover",
     } else if (type == "hyet") {
 
       if (!is.null(dates)) {
-        plot(data~dates,type="h",pch=20,cex=0.7,ylim=c(ymin,ymax),main=main,xlab=xlab, ylab=ylab, mgp = c(1.7, 0.6, 0))
+        plot(data~dates,type="h",pch=20,cex=0.7,ylim=c(ymin,ymax),xlim=c(xmin,xmax),main=main,xlab=xlab, ylab=ylab, mgp = c(1.7, 0.6, 0))
       } else {
-        plot(data,type="h",pch=20,cex=0.7,ylim=c(ymin,ymax),main=main,xlab=xlab, ylab=ylab, mgp = c(1.7, 0.6, 0))
+        plot(data,type="h",pch=20,cex=0.7,ylim=c(ymin,ymax),xlim=c(xmin,xmax),main=main,xlab=xlab, ylab=ylab, mgp = c(1.7, 0.6, 0))
       }
 
       extevents = eventid = list()
